ioutil

package
v0.0.0-...-66e3b3a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 7, 2025 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func TempDir

func TempDir(fs absfs.FileSystem, dir, prefix string) (name string, err error)

TempDir creates a new temporary directory in the directory dir of the absfs.FileSystem fs with a name beginning with prefix and returns the path of the new directory. If dir is the empty string, TempDir uses the default directory for temporary files (see os.TempDir). Multiple programs calling TempDir simultaneously will not choose the same directory. It is the caller's responsibility to remove the directory when no longer needed.

func TempFile

func TempFile(fs absfs.FileSystem, dir, prefix string) (f absfs.File, err error)

TempFile creates a new temporary file in the directory dir of the absfs.FileSystem fs with a name beginning with prefix, opens the file for reading and writing, and returns the resulting absfs.File. If dir is the empty string, TempFile uses the default directory for temporary files for the given FileSystem (see absfs.TempDir). Multiple programs calling TempFile simultaneously will not choose the same file. The caller can use f.Name() to find the pathname of the file. It is the caller's responsibility to remove the file when no longer needed.

Types

This section is empty.

Jump to